@@ -7,8 +7,8 @@ warning = FALSE,
 message = FALSE,
 error = FALSE,
 outwidth = "100%",
-fig.width = 8,
-fig.height = 6,
+fig.width = 6,
+fig.height = 4,
 fig.align = "center")
 
 ## -----------------------------------------------------------------------------
@@ -26,6 +26,8 @@ data(school)
 #loading the country data
 data(countrycode)
 
+selected_countries = c("AUS", "FIN", "JPN", "USA", "NZL", "ESP")
+
 #joining the student, school dataset
 school_student_subset_2018 <- left_join(
   student_subset_2018, 
@@ -33,17 +35,13 @@ school_student_subset_2018 <- left_join(
   by = c("school_id", "country", "year")) 
 
 #check the count of public and private schools in the a few randomly selected countries
-school_student_subset_2018 %>% 
-  dplyr::filter(country %in% c("AUS", "QAT", "USA" , "JPN", 
-                              "ALB", "PER", "FIN",  "SGP")) %>%
-  group_by(country, public_private) %>% 
-  tally() %>% 
-  dplyr::mutate(percent = n/sum(n)) %>% 
-  dplyr::ungroup() %>% 
-  left_join(countrycode, by = "country") %>% 
-  dplyr::mutate(country_name = fct_relevel(
-    country_name, 
-    c("Finland", "United States", "Albania", "Peru", "Japan", "Qatar", "Australia"))) %>% 
+school_student_subset_2018 |> 
+  dplyr::filter(country %in% selected_countries) |>
+  group_by(country, public_private) |> 
+  tally() |> 
+  dplyr::mutate(percent = n/sum(n)) |> 
+  dplyr::ungroup() |> 
+  left_join(countrycode, by = "country") |> 
   ggplot(aes(x = percent,
              y = country_name,
              fill = public_private)) +
@@ -55,26 +53,25 @@ school_student_subset_2018 %>%
        x = "Percentage of schools",
        fill = "")
 
-## ---- echo= FALSE-------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 student_data_2018 <- load_student("2018")
-
 data(school)
+
 data(countrycode)
 
 school_student_2018 <- left_join(
   student_data_2018, 
-  school, 
+  school,
   by = c("school_id", "country", "year"))
 
-school_student_2018 %>%
-  dplyr::filter(country %in% c("AUS", "QAT", "USA" , "JPN", 
-                               "ALB", "PER", "FIN",  "SGP")) %>% 
-  group_by(country) %>% 
-  summarise(avg_fund_gov = mean(fund_gov, na.rm = TRUE)) %>% 
-  arrange(avg_fund_gov) %>% 
-  mutate(country = fct_reorder(country, avg_fund_gov)) %>% 
-  left_join(countrycode, by = "country") %>% 
-  mutate(country_name = fct_reorder(country_name, avg_fund_gov)) %>% 
+school_student_2018 |>
+  dplyr::filter(country %in% selected_countries) |> 
+  group_by(country) |> 
+  summarise(avg_fund_gov = mean(fund_gov, na.rm = TRUE)) |> 
+  arrange(avg_fund_gov) |> 
+  mutate(country = fct_reorder(country, avg_fund_gov)) |> 
+  left_join(countrycode, by = "country") |> 
+  mutate(country_name = fct_reorder(country_name, avg_fund_gov)) |> 
   ggplot(aes(x=country_name, y=avg_fund_gov)) +
   geom_segment(aes(xend=country_name, yend=0)) +
   geom_point(size=4, color="orange") +
